The **docker-banner-gen** command-line tool allows you to generate
`bash.bashrc` files to be used within Docker containers. 
It is based on TensorFlow's `bash.bashrc` and uses pyfiglet to
generate the banner.
